---
name: Bug Report
about: Report a problem using F´
title: ''
labels: bug
assignees: ''

---
| | |
|:---|:---|
|**_F´ Version_**| |
|**_Affected Component_**|   |
---
## Problem Description

A description of the problem with sufficient detail to understand the issue.

## How to Reproduce

1. 
2.
3.

## Expected Behavior

A description of the expected behavior.
